@@ -138,7 +138,7 @@ def start():
     if webapp:
         _log.info('Starting web application ...')
 
-        web_app_file_name = os.path.abspath(DockerENT.__file__) + '/web_app.py'
+        web_app_file_name = os.path.dirname(DockerENT.__file__) + '/web_app.py'
         web_app_cmd = "streamlit run " + web_app_file_name
 
         with subprocess.Popen(web_app_cmd.split(" ")) as web_process:
